##  Configuring Settings for Syncing Fields and Establishing Relations
As an admin, you can configure how to use catalog data for application fact sheets. Follow these steps:
  1. In the administration area, navigate to the Reference Catalog section, then go to the Application tab.
  2. Select the data fields that you want to sync from the catalog.
  3. Choose whether you want to set relations to IT components. If you select this option, you can also enable setting relations to providers and tech categories related to IT components.
  4. Click Save.
